@@ -29,49 +29,42 @@ src_mongo <- function(collection = "test", db = "test",
 
   # check minimum version
   pkgNeeded("mongolite", "1.6")
-  
+
   # create connection
   con <- mongolite::mongo(collection, db, url, ...)
 
   # potential security concern with
   # storing the full connection string
-  structure(list(con = con,
-                 collection = collection,
-                 db = db,
-                 url = url,
-                 ...),
-            class = c("src_mongo", "docdb_src"))
+  structure(
+    list(
+      con = con,
+      collection = collection,
+      db = db,
+      url = url,
+      ...),
+    class = c("src_mongo", "docdb_src"))
 }
 
 #' @export
 print.src_mongo <- function(x, ...) {
-  con  <- x$con
-  coll <- x$collection
-  db   <- x$db
-  url  <- x$url
 
   # rights may be insufficient to call info(),
   # hence try() block and fallback printout
   tmp <- try({
-    srv <- con$info()
-    cat(
-      "MongoDB ",
-      # not all compatible server deployments return information
-      sprintf("%s (uptime: %ss)", srv$server$version, srv$server$uptime),
-      sprintf("\nURL: %s\nDatabase: %s\nCollection: %s\n", url, db, coll)
-    )
+    srv <- x$con$info()
+    srcInfo("MongoDB", srv$server$version, x$db, srv$stats$size)
   }, silent = TRUE)
 
   if (inherits(tmp, "try-error")) {
-    cat(sprintf("MongoDB \nURL: %s\nDatabase: %s\nCollection: %s\n",
-                url, db, coll))
-
+    srcInfo("MongoDB", NA, x$db, NA)
   }
+
 }
 
 #' @keywords internal
 #' @noRd
 chkSrcMongo <- function(src, key = NULL) {
+
   if (exists("key", inherits = FALSE) && src$collection != key) {
     warning("Parameter 'key' = '", key, "' differs from 'collection' = '",
             src$collection, "' that was specified in src_mongo();",
