@@ -1,12 +1,12 @@
 test_that("Source", {
-  skip_if_no_sqlite()
   skip_on_cran()
+  skip_if_no_sqlite()
 
   # creating database connection has
   # unique parameters, see README.Rmd
   dbSrcKey <- function() {
     testKey <- createKey()
-    testSrc <- src_sqlite()
+    testSrc <- suppressWarnings(src_sqlite())
     return(list(testKey = testKey, testSrc = testSrc))
   }
 
@@ -14,7 +14,7 @@ test_that("Source", {
   tmp <- dbSrcKey()
   expect_is(tmp$testSrc, "docdb_src")
   expect_is(tmp$testSrc, "src_sqlite")
-  expect_output(suppressWarnings(print(tmp$testSrc)), "src: sqlite")
+  expect_output(print(tmp$testSrc), "src: SQLite")
   RSQLite::dbDisconnect(tmp$testSrc$con)
   rm(tmp)
 
